@@ -15,25 +15,30 @@ class CreditsWnd;
 class IntroScreen : public GG::Wnd {
 public:
     /** \name Structors*/ //!@{
-    IntroScreen();                              //!< default ctor
-    ~IntroScreen();                             //!< default dtor
+    IntroScreen();
+
+    ~IntroScreen();
     //!@}
 
     /** \name Mutators*/ //!@{
+    void KeyPress(GG::Key key, std::uint32_t key_code_point, GG::Flags<GG::ModKey> mod_keys) override;
+
+    void Render() override;
+
     void            OnSinglePlayer();  //!< called when single player is clicked
     void            OnQuickStart();    //!< called when quick start is clicked
     void            OnMultiPlayer();   //!< ...
     void            OnLoadGame();
     void            OnOptions();
+    void            OnPedia();
     void            OnAbout();
     void            OnWebsite();
     void            OnCredits();
     void            OnExitGame();
-    virtual void    KeyPress (GG::Key key, boost::uint32_t key_code_point, GG::Flags<GG::ModKey> mod_keys);
+
 
     void            DoLayout();
     virtual void    Close();
-    virtual void    Render();
     //!@}
 
 private:
@@ -42,6 +47,7 @@ private:
     GG::Button*         m_multi_player; //!< opens up the multi player game dialog
     GG::Button*         m_load_game;    //!< loads a saved single player game
     GG::Button*         m_options;      //!< opens the options dialog
+    GG::Button*         m_pedia;        //!< shows the pedia window
     GG::Button*         m_about;        //!< opens a dialog to choose to see credits or license
     GG::Button*         m_website;      //!< opens web browser (or however system handles urls) to http://freeorion.org
     GG::Button*         m_credits;      //!< displays credits
