@@ -1,5 +1,6 @@
 #!/usr/bin/env python2
 
+
 import sys
 import os
 from string import Template
@@ -42,10 +43,9 @@ class Generator(object):
 
     def execute(self, version, branch, build_no, build_sys):
         if build_no == INVALID_BUILD_NO:
-            print "WARNING: Can't determine git commit, %s not updated!" % self.outfile
-            return
+            print "WARNING: Can't determine git commit!"
 
-        if os.path.isfile(self.outfile):
+        if os.path.isfile(self.outfile) and not build_no == INVALID_BUILD_NO:
             with open(self.outfile) as check_file:
                 if build_no in check_file.read():
                     return
@@ -65,14 +65,14 @@ class Generator(object):
 class NsisInstScriptGenerator(Generator):
     def compile_dll_list(self):
         all_dll_files = glob("*.dll")
-        accepted_dll_files = []
+        accepted_dll_files = set(["GiGi.dll", "GiGiSDL.dll"])
         for dll_file in all_dll_files:
             if dll_file.startswith("boost_"):
                 if dll_file.partition("-")[0] in required_boost_libraries:
-                    accepted_dll_files.append(dll_file)
+                    accepted_dll_files.add(dll_file)
             else:
-                accepted_dll_files.append(dll_file)
-        return accepted_dll_files
+                accepted_dll_files.add(dll_file)
+        return sorted(accepted_dll_files)
 
     def compile_output(self, template, version, branch, build_no, build_sys):
         dll_files = self.compile_dll_list()
@@ -105,8 +105,7 @@ build_sys = sys.argv[2]
 
 # A list of tuples containing generators
 generators = [
-    Generator('util/Version.cpp.in', 'util/Version.cpp'),
-    Generator('doc/apidoc-commit-message.in', 'doc/apidoc-commit-message')
+    Generator('util/Version.cpp.in', 'util/Version.cpp')
 ]
 if system() == 'Windows':
     generators.append(NsisInstScriptGenerator('Installer/FreeOrion_Install_Script.nsi.in',
@@ -114,7 +113,7 @@ if system() == 'Windows':
 if system() == 'Darwin':
     generators.append(Generator('Xcode/Info.plist.in', 'Xcode/Info.plist'))
 
-version = "0.4.6"
+version = "0.4.7"
 branch = ""
 build_no = INVALID_BUILD_NO
 
@@ -124,11 +123,11 @@ try:
         branch = ""
     else:
         branch += " "
-    commit = check_output(["git", "show", "-s", "--format=%h", "HEAD"]).strip()
+    commit = check_output(["git", "show", "-s", "--format=%h", "--abbrev=7", "HEAD"]).strip()
     timestamp = float(check_output(["git", "show", "-s", "--format=%ct", "HEAD"]).strip())
     build_no = ".".join([datetime.utcfromtimestamp(timestamp).strftime("%Y-%m-%d"), commit])
 except:
-    print "WARNING: git not installed"
+    print "WARNING: git not installed or not setup correctly"
 
 for generator in generators:
     generator.execute(version, branch, build_no, build_sys)
