@@ -1,3 +1,24 @@
+"""
+This module stores information about game rules and content that can not be dynamically accessed.
+
+If other modules rely on information regarding the game content that can not be queried from the server and thus
+ needs to be hardcoded, the information should be implemented here and referenced by the other module.
+
+The game content is sorted by categories:
+    - Basic Game Rules
+    - Species
+    - Specials
+    - Techs
+    - Buildings
+    - Shipdesign / -parts
+Each category is wrapped by <editor-fold desc="CATEGORY">   </editor-fold> tags which allow code-folding in IDE.
+Categories may have subcategories which are also wrapped by these tags. When adding new content, try to keep it
+structured in the aforementioned way. Use the category names to find the appropriate section of the file.
+
+Example usage:
+    import AIDependencies
+    my_industry = AIDependencies.INDUSTRY_PER_POP * my_population
+"""
 import freeOrionAIInterface as fo  # interface used to interact with FreeOrion AI client  # pylint: disable=import-error
 
 # Note re common dictionary lookup structure, "PlanetSize-Dependent-Lookup":
@@ -17,29 +38,67 @@ import freeOrionAIInterface as fo  # interface used to interact with FreeOrion A
 #     }
 # Please refer to the building_supply dictionary below for an example that displays both of these uses.
 
-#
-#  Miscellaneous
-#
-
+# <editor-fold desc="Basic Game Rules">
 # TODO look into (enabling) simply retrieving the below values via UserString
 INDUSTRY_PER_POP = 0.2
-
 RESEARCH_PER_POP = 0.2
-
 TROOPS_PER_POP = 0.2
 
+PROT_FOCUS_MULTIPLIER = 2.0
 TECH_COST_MULTIPLIER = 2.0
 
-# Species modifiers (except for weapons, hangars, fighters)
-SPECIES_RESEARCH_MODIFIER = {'NO': 0.0, 'BAD': 0.75, 'GOOD': 1.5, 'GREAT': 2.0, 'ULTIMATE': 3.0}
-SPECIES_INDUSTRY_MODIFIER = {'NO': 0.0, 'BAD': 0.75, 'GOOD': 1.5, 'GREAT': 2.0, 'ULTIMATE': 3.0}
-SPECIES_POPULATION_MODIFIER = {'BAD': 0.75, 'GOOD': 1.25}
-SPECIES_SUPPLY_MODIFIER = {'BAD': 0, 'AVERAGE': 1, 'GREAT': 2, 'ULTIMATE': 3}
+# Colonization details
+COLONY_POD_COST = 120  # TODO Query directly from part
+OUTPOST_POD_COST = 50  # TODO Query directly from part
+COLONY_POD_UPKEEP = 0.06
+SHIP_UPKEEP = 0.01
+
+#  Supply details
+supply_by_size = {
+    fo.planetSize.tiny: 2,
+    fo.planetSize.small: 1,
+    fo.planetSize.large: -1,
+    fo.planetSize.huge: -2,
+    fo.planetSize.gasGiant: -1,
+}
+
+# Drydock repair details
+DRYDOCK_HAPPINESS_THRESHOLD = 5
+
+# Constants defined by the C++ game engine
+INVALID_ID = -1
+
+# </editor-fold>
 
 
-#
-# Specials details (some specials are instead covered in the section they most directly affect
-#
+# <editor-fold desc="Environmental population modifiers">
+#  Population modifiers that are based on environment
+
+# boni that scale with planet size
+POP_SIZE_MOD_MAP = {
+    # "Effect": [uninhab, hostile, poor, adequate, good]
+    "environment_bonus": [0,-4,-2, 0, 3],
+    "GRO_SUBTER_HAB":    [0, 1, 1, 1, 1],
+    "GRO_SYMBIOTIC_BIO": [0, 0, 1, 1, 1],
+    "GRO_XENO_GENETICS": [0, 1, 2, 2, 0],
+    "GRO_XENO_HYBRID":   [0, 2, 1, 0, 0],
+    "GRO_CYBORG":        [0, 2, 0, 0, 0],
+    "CON_NDIM_STRUC":    [0, 2, 2, 2, 2],
+    "CON_ORBITAL_HAB":   [0, 1, 1, 1, 1],
+}
+
+# flat boni not dependent on size
+POP_CONST_MOD_MAP = {
+    # "Source": [uninhab, hostile, poor, adequate, good]
+    "GRO_PLANET_ECOL":   [0, 0, 0, 1, 1],
+    "GRO_SYMBIOTIC_BIO": [0, 0, 0,-1,-1],
+}
+# </editor-fold>
+
+
+# <editor-fold desc="Specials">
+# <editor-fold desc="Growth Focus specials">
+# stores growth special per metabolism
 metabolismBoostMap = {
     "ORGANIC": [
         "FRUIT_SPECIAL",
@@ -61,29 +120,19 @@ metabolismBoostMap = {
     ],
 }
 
+# stores which metabolism profits from each special - autogenerated DO NOT EDIT
 metabolismBoosts = {}
 for metab, boosts in metabolismBoostMap.items():
     for boost in boosts:
         metabolismBoosts[boost] = metab
+# </editor-fold>
 
-HONEYCOMB_IND_MULTIPLIER = 2.5
-COMPUTRONIUM_RES_MULTIPLIER = 1.0
-
-# Colonization details
-COLONY_POD_COST = 120
-COLONY_POD_UPKEEP = 0.06
-OUTPOST_POD_COST = 50
-SHIP_UPKEEP = 0.01
-
-OUTPOSTING_TECH = "SHP_GAL_EXPLO"
-
+# <editor-fold desc="Other Population changing specials">
 # Please see the Note at top of this file regarding PlanetSize-Dependent-Lookup
 # Regardless of whether the sub-dictionary here has PlanetSize keys, the final
 # value will be applied as a *fixed-size mod* to the max population
 POP_FIXED_MOD_SPECIALS = {
-    'DIM_RIFT_MASTER_SPECIAL': {
-        -1: -4,
-    },
+    'DIM_RIFT_MASTER_SPECIAL': {-1: -4},
 }
 
 # Please see the Note at top of this file regarding PlanetSize-Dependent-Lookup
@@ -103,21 +152,17 @@ POP_PROPORTIONAL_MOD_SPECIALS = {
         -1: -5,
     },
 }
+# </editor-fold>
 
-#  Supply details
-supply_range_techs = {
-    "CON_ORBITAL_CON": 1,
-    "CON_CONTGRAV_ARCH": 1,
-    "CON_GAL_INFRA": 1,
-}
-supply_by_size = {
-    fo.planetSize.tiny: 2,
-    fo.planetSize.small: 1,
-    fo.planetSize.large: -1,
-    fo.planetSize.huge: -2,
-    fo.planetSize.gasGiant: -1,
-}
+# <editor-fold desc="Industry related specials">
+HONEYCOMB_IND_MULTIPLIER = 2.5
+# </editor-fold>
 
+# <editor-fold desc="Research related specials">
+COMPUTRONIUM_RES_MULTIPLIER = 1.0
+# </editor-fold>
+
+# <editor-fold desc="Supply related specials">
 SUPPLY_MOD_SPECIALS = {
     'WORLDTREE_SPECIAL': {
         -1: 1,
@@ -129,27 +174,15 @@ SUPPLY_MOD_SPECIALS = {
         -1: -1,
     },
 }
+# </editor-fold>
 
-# Please see the Note at top of this file regarding PlanetSize-Dependent-Lookup
-# building supply bonuses are keyed by planet size; key -1 stands for any planet size
-building_supply = {
-    "BLD_IMPERIAL_PALACE": {
-        -1: 2,
-    },
-    "BLD_MEGALITH": {
-        -1: 2,
-    },
-    "BLD_SPACE_ELEVATOR": {
-        fo.planetSize.tiny: 1,
-        fo.planetSize.small: 2,
-        fo.planetSize.medium: 3,
-        fo.planetSize.large: 4,
-        fo.planetSize.huge: 5,
-        fo.planetSize.gasGiant: 4,
-    },
-}
 
-# tech names etc.
+# </editor-fold>
+
+
+# <editor-fold desc="Techs">
+# <editor-fold desc="Various tech names">
+# For IDE support and to avoid typos and easier editing, define tech names here and import for scripts
 GRO_LIFE_CYCLE = "GRO_LIFECYCLE_MAN"
 PRO_ORBITAL_GEN = "PRO_ORBITAL_GEN"
 PRO_SOL_ORB_GEN = "PRO_SOL_ORB_GEN"
@@ -161,6 +194,8 @@ NEST_DOMESTICATION_TECH = "SHP_DOMESTIC_MONSTER"
 ART_MINDS = "LRN_ARTIF_MINDS"
 LRN_ALGO_ELEGANCE = "LRN_ALGO_ELEGANCE"
 GRO_PLANET_ECOL = "GRO_PLANET_ECOL"
+GRO_SUBTER_HAB = "GRO_SUBTER_HAB"
+LRN_PHYS_BRAIN = "LRN_PHYS_BRAIN"
 LRN_QUANT_NET = "LRN_QUANT_NET"
 LRN_XENOARCH = "LRN_XENOARCH"
 LRN_ART_BLACK_HOLE = "LRN_ART_BLACK_HOLE"
@@ -170,17 +205,46 @@ GRO_GENOME_BANK = "GRO_GENETIC_MED"
 
 CON_CONC_CAMP = "CON_CONC_CAMP"
 
-# (k,v) exclude tech k if aggression is less than v
-TECH_EXCLUSION_MAP_1 = {
-    "LRN_TRANSCEND": fo.aggression.typical,
-}
-# (k,v) exclude tech k if aggression is greater than v
-TECH_EXCLUSION_MAP_2 = {
-}
+SPY_STEALTH_1 = "SPY_STEALTH_1"
+SPY_STEALTH_2 = "SPY_STEALTH_2"
+# </editor-fold>
 
+
+# Tech required to build outpost pods
+OUTPOSTING_TECH = "SHP_GAL_EXPLO"
+
+# <editor-fold desc="Supply techs">
+supply_range_techs = {
+    "CON_ORBITAL_CON": 1,
+    "CON_CONTGRAV_ARCH": 1,
+    "CON_GAL_INFRA": 1,
+}
+# </editor-fold>
+
+# <editor-fold desc="Industry bossting techs">
+# Industry modifiers per population - [[EARLY_PRIORITY]]: Affected by species modifiers
+INDUSTRY_EFFECTS_PER_POP_MODIFIED_BY_SPECIES = {
+    "PRO_FUSION_GEN": 1.0,
+    "GRO_ENERGY_META": 1.0,
+    "PRO_INDUSTRY_CENTER_I": 1.0,
+    "PRO_INDUSTRY_CENTER_II": 1.0,
+    "PRO_INDUSTRY_CENTER_III": 1.0,
+}
+# Industry modifiers per population - [[LATE_PRIORITY]] or later: Not affected by species modifiers
+INDUSTRY_EFFECTS_PER_POP_NOT_MODIFIED_BY_SPECIES = {
+    "PRO_ROBOTIC_PROD": 0.5,
+    "PRO_SOL_ORB_GEN": 2.0,  # TODO don't assume will build a gen at a blue/white star
+    PRO_SINGULAR_GEN: 5.0,
+}
+# </editor-fold>
+
+
+# <editor-fold desc="Defense techs">
+# TODO are these 3 necessary? Could rely on ordered DEFENSE_SHIELD_TECHS (Morlic)
 FIRST_PLANET_SHIELDS_TECH = "LRN_FORCE_FIELD"
 PLANET_BARRIER_I_TECH = "DEF_PLAN_BARRIER_SHLD_1"
 DEFENSE_REGEN_1_TECH = "DEF_DEFENSE_NET_REGEN_1"
+
 DEFENSE_DEFENSE_NET_TECHS = ["DEF_DEFENSE_NET_1", "DEF_DEFENSE_NET_2", "DEF_DEFENSE_NET_3"]
 DEFENSE_REGEN_TECHS = [
     "DEF_DEFENSE_NET_REGEN_1",
@@ -200,8 +264,60 @@ DEFENSE_SHIELDS_TECHS = [
     "DEF_PLAN_BARRIER_SHLD_4",
     "DEF_PLAN_BARRIER_SHLD_5",
 ]
+# </editor-fold>
 
-PROT_FOCUS_MULTIPLIER = 2.0
+# <editor-fold desc="Weapon techs">
+# TODO (Morlic): Consider using only 1 dict with (capacity, secondaryStat) tuple as entries
+WEAPON_UPGRADE_DICT = {
+    # "PARTNAME": tuple((tech_name, dmg_upgrade), (tech_name2, dmg_upgrade2), ...)
+    "SR_WEAPON_0_1": (),
+    "SR_WEAPON_1_1": tuple(("SHP_WEAPON_1_%d" % i, 1) for i in [2, 3, 4]),
+    "SR_WEAPON_2_1": tuple(("SHP_WEAPON_2_%d" % i, 2) for i in [2, 3, 4]),
+    "SR_WEAPON_3_1": tuple(("SHP_WEAPON_3_%d" % i, 3) for i in [2, 3, 4]),
+    "SR_WEAPON_4_1": tuple(("SHP_WEAPON_4_%d" % i, 5) for i in [2, 3, 4]),
+    "SR_SPINAL_ANTIMATTER": (),
+}
+
+WEAPON_ROF_UPGRADE_DICT = {
+    # "PARTNAME": tuple((tech_name, rof_upgrade), (tech_name2, rof_upgrade2), ...)
+    "SR_WEAPON_0_1": (),
+    "SR_WEAPON_1_1": (),
+    "SR_WEAPON_2_1": (),
+    "SR_WEAPON_3_1": (),
+    "SR_WEAPON_4_1": (),
+    "SR_SPINAL_ANTIMATTER": (),
+}
+
+FIGHTER_DAMAGE_UPGRADE_DICT = {
+    # "PARTNAME": tuple((tech_name, dmg_upgrade), (tech_name2, dmg_upgrade2), ...)
+    "FT_HANGAR_1": (("SHP_FIGHTERS_2", 1), ("SHP_FIGHTERS_3", 1), ("SHP_FIGHTERS_4", 1)),
+    "FT_HANGAR_2": (("SHP_FIGHTERS_2", 2), ("SHP_FIGHTERS_3", 3), ("SHP_FIGHTERS_4", 5)),
+    "FT_HANGAR_3": (("SHP_FIGHTERS_2", 3), ("SHP_FIGHTERS_3", 4), ("SHP_FIGHTERS_4", 7)),
+    "FT_HANGAR_4": (),
+}
+
+FIGHTER_CAPACITY_UPGRADE_DICT = {
+    # "PARTNAME": tuple((tech_name, capacity_upgrade), (tech_name2, capacity_upgrade2), ...)
+    "FT_HANGAR_1": (),
+    "FT_HANGAR_2": (),
+    "FT_HANGAR_3": (),
+    "FT_HANGAR_4": (),
+}
+
+# DO NOT TOUCH THIS ENTRY BUT UPDATE WEAPON_UPGRADE_DICT INSTEAD!
+WEAPON_UPGRADE_TECHS = [tech_name for tups in WEAPON_UPGRADE_DICT.values() for (tech_name, _) in tups]
+# </editor-fold>
+
+# <editor-fold desc="Tech Groups for Automated Research Approach">
+
+# TODO: I don't think this should be in AIDependencies... (Morlic)
+# (k,v) exclude tech k if aggression is less than v
+TECH_EXCLUSION_MAP_1 = {
+    "LRN_TRANSCEND": fo.aggression.typical,
+}
+# (k,v) exclude tech k if aggression is greater than v
+TECH_EXCLUSION_MAP_2 = {
+}
 
 # TODO obtain this information from techs
 UNRESEARCHABLE_TECHS = (
@@ -241,7 +357,6 @@ UNUSED_TECHS = (
 )
 
 THEORY_TECHS = (
-    "LRN_PHYS_BRAIN",
     "LRN_TRANSLING_THT",
     "LRN_PSIONICS",
     "LRN_GRAVITONICS",
@@ -274,6 +389,7 @@ PRODUCTION_BOOST_TECHS = (
 RESEARCH_BOOST_TECHS = (
     "LRN_ALGO_ELEGANCE",
     "LRN_ARTIF_MINDS",
+    "LRN_PHYS_BRAIN",
     "LRN_DISTRIB_THOUGHT",
     "LRN_QUANT_NET",
     "LRN_STELLAR_TOMOGRAPHY",
@@ -369,6 +485,7 @@ DAMAGE_CONTROL_TECHS = (
 )
 
 WEAPON_PREFIX = "SHP_WEAPON"
+
 ARMOR_TECHS = (
     "SHP_ZORTRIUM_PLATE",
     "SHP_DIAMOND_PLATE",
@@ -406,22 +523,111 @@ SHIP_TECHS_REQUIRING_BLACK_HOLE = (
     "SHP_SOLAR_CONT",
 )
 
+# </editor-fold>
 
-# Industry modifiers per population - [[EARLY_PRIORITY]]: Affected by species modifiers
-INDUSTRY_EFFECTS_PER_POP_MODIFIED_BY_SPECIES = {
-    "PRO_FUSION_GEN": 1.0,
-    "GRO_ENERGY_META": 1.0,
-    "PRO_INDUSTRY_CENTER_I": 1.0,
-    "PRO_INDUSTRY_CENTER_II": 1.0,
-    "PRO_INDUSTRY_CENTER_III": 1.0,
-}
-# Industry modifiers per population - [[LATE_PRIORITY]] or later: Not affected by species modifiers
-INDUSTRY_EFFECTS_PER_POP_NOT_MODIFIED_BY_SPECIES = {
-    "PRO_ROBOTIC_PROD": 0.5,
-    "PRO_SOL_ORB_GEN": 2.0,  # TODO don't assume will build a gen at a blue/white star
-    PRO_SINGULAR_GEN: 5.0,
+# </editor-fold>
+
+
+# <editor-fold desc="Species">
+# species names
+SP_LAMBALALAM = "SP_LEMBALALAM"
+
+# Species modifiers
+SPECIES_RESEARCH_MODIFIER = {'NO': 0.0, 'BAD': 0.75, 'GOOD': 1.5, 'GREAT': 2.0, 'ULTIMATE': 3.0}
+SPECIES_INDUSTRY_MODIFIER = {'NO': 0.0, 'BAD': 0.75, 'GOOD': 1.5, 'GREAT': 2.0, 'ULTIMATE': 3.0}
+SPECIES_POPULATION_MODIFIER = {'BAD': 0.75, 'GOOD': 1.25}
+SPECIES_SUPPLY_MODIFIER = {'BAD': 0, 'AVERAGE': 1, 'GREAT': 2, 'ULTIMATE': 3}
+
+# <editor-fold desc="XenoResurrectionSpecies">
+EXTINCT_SPECIES = [
+    "BANFORO",
+    "KILANDOW",
+    "MISIORLA"
+]
+# </editor-fold>
+
+# <editor-fold desc="Piloting traits">
+# TODO (Morlic): Consider using only 1 dict with tuple for (Capacity, SecondaryStat) effects
+PILOT_DAMAGE_MODIFIER_DICT = {
+    # TRAIT:    {weapon_name: effect, weapon_name2: effect2,...}
+    "NO":       {},
+    "BAD":      {"SR_WEAPON_1_1": -1, "SR_WEAPON_2_1": -2, "SR_WEAPON_3_1": -3, "SR_WEAPON_4_1": -5},
+    "GOOD":     {"SR_WEAPON_1_1":  1, "SR_WEAPON_2_1":  2, "SR_WEAPON_3_1":  3, "SR_WEAPON_4_1": 5},
+    "GREAT":    {"SR_WEAPON_1_1":  2, "SR_WEAPON_2_1":  4, "SR_WEAPON_3_1":  6, "SR_WEAPON_4_1": 10},
+    "ULTIMATE": {"SR_WEAPON_1_1":  3, "SR_WEAPON_2_1":  6, "SR_WEAPON_3_1":  9, "SR_WEAPON_4_1": 15, "SR_WEAPON_0_1": 1},
 }
 
+PILOT_ROF_MODIFIER_DICT = {
+    # TRAIT:    {weapon_name: effect, weapon_name2: effect2,...}
+    "NO":       {},
+    "BAD":      {"SR_WEAPON_0_1": -1},
+    "GOOD":     {"SR_WEAPON_0_1": 1},
+    "GREAT":    {"SR_WEAPON_0_1": 2},
+    "ULTIMATE": {"SR_WEAPON_0_1": 3},
+}
+
+PILOT_FIGHTERDAMAGE_MODIFIER_DICT = {
+    # TRAIT:    {hangar_name: effect, hangar_name2: effect2,...}
+    "NO":       {},
+    "BAD":      {"FT_HANGAR_1": -1, "FT_HANGAR_2": -2, "FT_HANGAR_3": -3, "FT_HANGAR_4": -4},
+    "GOOD":     {"FT_HANGAR_1":  1, "FT_HANGAR_2":  2, "FT_HANGAR_3":  3, "FT_HANGAR_4": 4},
+    "GREAT":    {"FT_HANGAR_1":  2, "FT_HANGAR_2":  4, "FT_HANGAR_3":  6, "FT_HANGAR_4": 8},
+    "ULTIMATE": {"FT_HANGAR_1":  3, "FT_HANGAR_2":  6, "FT_HANGAR_3":  9, "FT_HANGAR_4": 12},
+}
+
+PILOT_FIGHTER_CAPACITY_MODIFIER_DICT = {
+    # TRAIT:    {hangar_name: effect, hangar_name2: effect2,...}
+    "NO":       {},
+    "BAD":      {},
+    "GOOD":     {},
+    "GREAT":    {},
+    "ULTIMATE": {},
+}
+# </editor-fold>
+
+# <editor-fold desc="Extraordinary Species Rules">
+# tag used if species self-destructs on conquest
+TAG_DESTROYED_ON_CONQUEST = "DESTROYED_ON_CONQUEST"
+
+# some species have a fixed population
+SPECIES_FIXED_POPULATION = {
+    # species_name: fixed_population_size
+    SP_LAMBALALAM: 5.0,
+}
+
+# techs that are unlocked if conquering a planet of a species
+SPECIES_TECH_UNLOCKS = {
+    # species: [tech1, tech2, ...]
+    SP_LAMBALALAM: [GRO_LIFE_CYCLE, SPY_STEALTH_1, SPY_STEALTH_2]
+}
+# </editor-fold>
+
+# </editor-fold>
+
+
+# <editor-fold desc="Buildings">
+# <editor-fold desc="Supply">
+# Please see the Note at top of this file regarding PlanetSize-Dependent-Lookup
+# building supply bonuses are keyed by planet size; key -1 stands for any planet size
+building_supply = {
+    "BLD_IMPERIAL_PALACE": {
+        -1: 2,
+    },
+    "BLD_MEGALITH": {
+        -1: 2,
+    },
+    "BLD_SPACE_ELEVATOR": {
+        fo.planetSize.tiny: 1,
+        fo.planetSize.small: 2,
+        fo.planetSize.medium: 3,
+        fo.planetSize.large: 4,
+        fo.planetSize.huge: 5,
+        fo.planetSize.gasGiant: 4,
+    },
+}
+# </editor-fold>
+
+# <editor-fold desc="Shipyards">
 # ship facilities info, dict keyed by building name, value is (min_aggression, prereq_bldg, base_cost, time)
 # not currently determined dynamically because it is initially used in a location-independent fashion
 # note that BLD_SHIPYARD_BASE is not an absolute prereq for BLD_NEUTRONIUM_FORGE, but is a practical one
@@ -447,8 +653,16 @@ SYSTEM_SHIP_FACILITIES = frozenset((
     "BLD_SHIPYARD_AST_REF",
 ))
 
+# </editor-fold>
+
+# </editor-fold>
+
+
+# <editor-fold desc="Shipdesign/-parts">
 PART_KRILL_SPAWNER = "SP_KRILL_SPAWNER"
 
+# <editor-fold desc="Effect Scripting for Shipdesigns">
+# <editor-fold desc="Tokens">
 # known tokens the AI can handle
 REPAIR_PER_TURN = "REPAIR_PER_TURN"
 FUEL_PER_TURN = "FUEL_PER_TURN"
@@ -459,11 +673,13 @@ SPEED = "SPEED"
 FUEL = "FUEL"
 SHIELDS = "SHIELDS"
 STRUCTURE = "STRUCTURE"
-DETECTION = "DETECTION"  # do only specify for hulls if irregular detection
+DETECTION = "DETECTION"            # do only specify for hulls if irregular detection
 ORGANIC_GROWTH = "ORGANIC_GROWTH"  # structure for value is (per_turn, maximum)
 STACKING_RULES = "STACKING_RULES"  # expects a list of stacking rules
-# stacking rules
-NO_EFFECT_WITH_CLOAKS = "NO_EFFECT_WITH_CLOAKS"
+# <editor-fold desc="Stacking rules">
+NO_EFFECT_WITH_CLOAKS = "NO_EFFECT_WITH_CLOAKS"  # part does not stack with cloak parts
+# </editor-fold>
+# </editor-fold>
 
 BASE_DETECTION = 25
 
@@ -598,42 +814,8 @@ PART_EFFECTS = {
     }
 }
 
-WEAPON_UPGRADE_DICT = {
-    # "PARTNAME": tuple((tech_name, dmg_upgrade), (tech_name2, dmg_upgrade2), ...)
-    "SR_WEAPON_1_1": tuple(("SHP_WEAPON_1_%d" % i, 1) for i in [2, 3, 4]),
-    "SR_WEAPON_2_1": tuple(("SHP_WEAPON_2_%d" % i, 2) for i in [2, 3, 4]),
-    "SR_WEAPON_3_1": tuple(("SHP_WEAPON_3_%d" % i, 3) for i in [2, 3, 4]),
-    "SR_WEAPON_4_1": tuple(("SHP_WEAPON_4_%d" % i, 5) for i in [2, 3, 4]),
-    "SR_WEAPON_0_1": (),
-    "SR_SPINAL_ANTIMATTER": (),
-}
+# </editor-fold>
 
-PILOT_DAMAGE_MODIFIER_DICT = {
-    # TRAIT:    {weapon_name: effect, weapon_name2: effect2,...}
-    "NO":       {},
-    "BAD":      {"SR_WEAPON_1_1": -1, "SR_WEAPON_2_1": -2, "SR_WEAPON_3_1": -3, "SR_WEAPON_4_1": -5},
-    "GOOD":     {"SR_WEAPON_1_1":  1, "SR_WEAPON_2_1":  2, "SR_WEAPON_3_1":  3, "SR_WEAPON_4_1": 5},
-    "GREAT":    {"SR_WEAPON_1_1":  2, "SR_WEAPON_2_1":  4, "SR_WEAPON_3_1":  6, "SR_WEAPON_4_1": 10},
-    "ULTIMATE": {"SR_WEAPON_1_1":  3, "SR_WEAPON_2_1":  6, "SR_WEAPON_3_1":  9, "SR_WEAPON_4_1": 15, "SR_WEAPON_0_1": 1},
-}
+# </editor-fold>
 
-PILOT_FIGHTERDAMAGE_MODIFIER_DICT = {
-    # TRAIT:    {hangar_name: effect, hangar_name2: effect2,...}
-    "NO":       {},
-    "BAD":      {"FT_HANGAR_1": -1, "FT_HANGAR_2": -2, "FT_HANGAR_3": -3, "FT_HANGAR_4": -4},
-    "GOOD":     {"FT_HANGAR_1":  1, "FT_HANGAR_2":  2, "FT_HANGAR_3":  3, "FT_HANGAR_4": 4},
-    "GREAT":    {"FT_HANGAR_1":  2, "FT_HANGAR_2":  4, "FT_HANGAR_3":  6, "FT_HANGAR_4": 8},
-    "ULTIMATE": {"FT_HANGAR_1":  3, "FT_HANGAR_2":  6, "FT_HANGAR_3":  9, "FT_HANGAR_4": 12},
-}
 
-PILOT_ROF_MODIFIER_DICT = {
-    # TRAIT:    {weapon_name: effect, weapon_name2: effect2,...}
-    "NO":       {},
-    "BAD":      {"SR_WEAPON_0_1": -1},
-    "GOOD":     {"SR_WEAPON_0_1": 1},
-    "GREAT":    {"SR_WEAPON_0_1": 2},
-    "ULTIMATE": {"SR_WEAPON_0_1": 3},
-}
-
-# DO NOT TOUCH THIS ENTRY BUT UPDATE WEAPON_UPGRADE_DICT INSTEAD!
-WEAPON_UPGRADE_TECHS = [tech_name for tups in WEAPON_UPGRADE_DICT.values() for (tech_name, _) in tups]
