@@ -7,8 +7,9 @@
 #include <GG/SignalsAndSlots.h>
 
 #include <boost/iterator/filter_iterator.hpp>
-#include <boost/thread/thread.hpp>
+#include <boost/asio/high_resolution_timer.hpp>
 
+#include <thread>
 
 using boost::asio::ip::tcp;
 using boost::asio::ip::udp;
@@ -30,19 +31,11 @@ private:
 
     boost::asio::ip::udp::socket   m_socket;
     boost::asio::ip::udp::endpoint m_remote_endpoint;
-    boost::array<char, 32>         m_recv_buffer;
+
+    std::array<char, 32> m_recv_buffer;
 };
 
 namespace {
-    void WriteMessage(boost::asio::ip::tcp::socket& socket, const Message& message) {
-        int header_buf[5];
-        HeaderToBuffer(message, header_buf);
-        std::vector<boost::asio::const_buffer> buffers;
-        buffers.push_back(boost::asio::buffer(header_buf));
-        buffers.push_back(boost::asio::buffer(message.Data(), message.Size()));
-        boost::asio::write(socket, buffers);
-    }
-
     struct PlayerID {
         PlayerID(int id) :
             m_id(id)
@@ -63,6 +56,7 @@ PlayerConnection::PlayerConnection(boost::asio::io_service& io_service,
                                    MessageAndConnectionFn nonplayer_message_callback,
                                    MessageAndConnectionFn player_message_callback,
                                    ConnectionFn disconnected_callback) :
+    m_service(io_service),
     m_socket(io_service),
     m_ID(INVALID_PLAYER_ID),
     m_new_connection(true),
@@ -72,8 +66,31 @@ PlayerConnection::PlayerConnection(boost::asio::io_service& io_service,
     m_disconnected_callback(disconnected_callback)
 {}
 
-PlayerConnection::~PlayerConnection()
-{ m_socket.close(); }
+PlayerConnection::~PlayerConnection() {
+    boost::system::error_code error;
+    m_socket.shutdown(boost::asio::ip::tcp::socket::shutdown_both, error);
+    if (error && (m_ID != INVALID_PLAYER_ID)) {
+        if (error == boost::asio::error::eof)
+            DebugLogger() << "Player connection disconnected by EOF from client.";
+        else if (error == boost::asio::error::connection_reset)
+            DebugLogger() << "Player connection disconnected, reset by client.";
+        else if (error == boost::asio::error::operation_aborted)
+            DebugLogger() << "Player operation aborted by server.";
+        else if (error == boost::asio::error::shut_down)
+            DebugLogger() << "Player connection shutdown.";
+        else if (error == boost::asio::error::connection_aborted)
+            DebugLogger() << "Player connection closed by server.";
+        else if (error == boost::asio::error::not_connected)
+            DebugLogger() << "Player connection already down.";
+        else {
+
+            ErrorLogger() << "PlayerConnection::~PlayerConnection: shutdown error #"
+                          << error.value() << " \"" << error.message() << "\""
+                          << " for player id " << m_ID;
+        }
+    }
+    m_socket.close();
+}
 
 bool PlayerConnection::EstablishedPlayer() const
 { return m_ID != INVALID_PLAYER_ID; }
@@ -93,8 +110,9 @@ bool PlayerConnection::IsLocalConnection() const
 void PlayerConnection::Start()
 { AsyncReadMessage(); }
 
-void PlayerConnection::SendMessage(const Message& message)
-{ WriteMessage(m_socket, message); }
+bool PlayerConnection::SendMessage(const Message& message) {
+    return SyncWriteMessage(message);
+}
 
 void PlayerConnection::EstablishPlayer(int id, const std::string& player_name, Networking::ClientType client_type,
                                        const std::string& client_version_string)
@@ -187,7 +205,9 @@ namespace {
         case Message::END_GAME:                 return "End Game";
         case Message::MODERATOR_ACTION:         return "Moderator Action";
         case Message::SHUT_DOWN_SERVER:         return "Shut Down Server";
+        case Message::AI_END_GAME_ACK:          return "Acknowledge Shut Down Server";
         case Message::REQUEST_SAVE_PREVIEWS:    return "Request save previews";
+        case Message::REQUEST_COMBAT_LOGS:      return "Request combat logs";
         default:                                return "Unknown Type";
         };
     }
@@ -199,9 +219,12 @@ void PlayerConnection::HandleMessageBodyRead(boost::system::error_code error,
     if (error) {
         if (error == boost::asio::error::eof ||
             error == boost::asio::error::connection_reset) {
+            ErrorLogger() << "PlayerConnection::HandleMessageBodyRead(): "
+                          << "error #" << error.value() << " \"" << error.message() << "\"";
             EventSignal(boost::bind(m_disconnected_callback, shared_from_this()));
         } else {
-            ErrorLogger() << "PlayerConnection::HandleMessageBodyRead(): error \"" << error << "\"";
+            ErrorLogger() << "PlayerConnection::HandleMessageBodyRead(): "
+                          << "error #" << error.value() << " \"" << error.message() << "\"";
         }
     } else {
         assert(static_cast<int>(bytes_transferred) <= m_incoming_header_buffer[4]);
@@ -239,28 +262,34 @@ void PlayerConnection::HandleMessageHeaderRead(boost::system::error_code error,
         // mask the problem.  For now, this is sufficient, since rapid
         // connects and disconnects are not a priority.
         if (m_new_connection) {
+            ErrorLogger() << "PlayerConnection::HandleMessageHeaderRead(): "
+                          << "new connection error #" << error.value() << " \""
+                          << error.message() << "\"" << " waiting for 0.5s";
             // wait half a second if the first data read is an error; we
             // probably just need more setup time
-            boost::this_thread::sleep_for(boost::chrono::milliseconds(500));
+            ErrorLogger() << "PlayerConnection::HandleMessageHeaderRead(): "
+                          << "new connection error #" << error.value() << " \""
+                          << error.message() << "\"" << " waiting for 0.5s";
+            std::this_thread::sleep_for(std::chrono::milliseconds(500));
         } else {
             if (error == boost::asio::error::eof ||
                 error == boost::asio::error::connection_reset) {
                 EventSignal(boost::bind(m_disconnected_callback, shared_from_this()));
             } else {
                 ErrorLogger() << "PlayerConnection::HandleMessageHeaderRead(): "
-                              << "error \"" << error << "\"";
+                              << "error #" << error.value() << " \"" << error.message() << "\"";
             }
         }
     } else {
         m_new_connection = false;
-        assert(static_cast<int>(bytes_transferred) <= HEADER_SIZE);
-        if (static_cast<int>(bytes_transferred) == HEADER_SIZE) {
-            BufferToHeader(m_incoming_header_buffer.c_array(), m_incoming_message);
+        assert(bytes_transferred <= Message::HeaderBufferSize);
+        if (bytes_transferred == Message::HeaderBufferSize) {
+            BufferToHeader(m_incoming_header_buffer, m_incoming_message);
             m_incoming_message.Resize(m_incoming_header_buffer[4]);
             boost::asio::async_read(
                 m_socket,
                 boost::asio::buffer(m_incoming_message.Data(), m_incoming_message.Size()),
-                boost::bind(&PlayerConnection::HandleMessageBodyRead, this,
+                boost::bind(&PlayerConnection::HandleMessageBodyRead, shared_from_this(),
                             boost::asio::placeholders::error,
                             boost::asio::placeholders::bytes_transferred));
         }
@@ -269,11 +298,38 @@ void PlayerConnection::HandleMessageHeaderRead(boost::system::error_code error,
 
 void PlayerConnection::AsyncReadMessage() {
     boost::asio::async_read(m_socket, boost::asio::buffer(m_incoming_header_buffer),
-                            boost::bind(&PlayerConnection::HandleMessageHeaderRead, this,
+                            boost::bind(&PlayerConnection::HandleMessageHeaderRead, 
+                                        shared_from_this(),
                                         boost::asio::placeholders::error,
                                         boost::asio::placeholders::bytes_transferred));
 }
 
+bool PlayerConnection::SyncWriteMessage(const Message& message) {
+    // Synchronously write and asynchronously signal the errors.  This prevents PlayerConnections
+    // being removed from the list while iterating to transmit to multiple receivers.
+    Message::HeaderBuffer header_buf;
+    HeaderToBuffer(message, header_buf);
+    std::vector<boost::asio::const_buffer> buffers;
+    buffers.push_back(boost::asio::buffer(header_buf));
+    buffers.push_back(boost::asio::buffer(message.Data(), message.Size()));
+
+    boost::system::error_code error;
+    boost::asio::write(m_socket, buffers, error);
+
+    if (error) {
+        ErrorLogger() << "PlayerConnection::WriteMessage(): player id = " << m_ID
+                      << " error #" << error.value() << " \"" << error.message();
+        boost::asio::high_resolution_timer t(m_service);
+        t.async_wait(boost::bind(&PlayerConnection::AsyncErrorHandler, this, error, boost::asio::placeholders::error));
+    }
+
+    return (!error);
+}
+
+void PlayerConnection::AsyncErrorHandler(boost::system::error_code handled_error, boost::system::error_code error) {
+    EventSignal(boost::bind(m_disconnected_callback, shared_from_this()));
+}
+
 ////////////////////////////////////////////////////////////////////////////////
 // DiscoveryServer
 ////////////////////////////////////////////////////////////////////////////////
@@ -310,7 +366,7 @@ ServerNetworking::ServerNetworking(boost::asio::io_service& io_service,
                                    MessageAndConnectionFn player_message_callback,
                                    ConnectionFn disconnected_callback) :
     m_host_player_id(Networking::INVALID_PLAYER_ID),
-    m_discovery_server(0),
+    m_discovery_server(nullptr),
     m_player_connection_acceptor(io_service),
     m_nonplayer_message_callback(nonplayer_message_callback),
     m_player_message_callback(player_message_callback),
@@ -359,10 +415,7 @@ ServerNetworking::const_established_iterator ServerNetworking::established_end()
 
 int ServerNetworking::NewPlayerID() const {
     int biggest_current_player_id(0);
-    for (PlayerConnections::const_iterator it = m_player_connections.begin();
-         it != m_player_connections.end(); ++it)
-    {
-        const PlayerConnectionPtr player = *it;
+    for (const PlayerConnectionPtr player : m_player_connections) {
         int player_id = player->PlayerID();
         if (player_id != INVALID_PLAYER_ID && player_id > biggest_current_player_id)
             biggest_current_player_id = player_id;
@@ -380,44 +433,42 @@ bool ServerNetworking::PlayerIsHost(int player_id) const {
 }
 
 bool ServerNetworking::ModeratorsInGame() const {
-    for (PlayerConnections::const_iterator it = m_player_connections.begin();
-         it != m_player_connections.end(); ++it)
-    {
-        const PlayerConnectionPtr player = *it;
+    for (const PlayerConnectionPtr player : m_player_connections) {
         if (player->GetClientType() == Networking::CLIENT_TYPE_HUMAN_MODERATOR)
             return true;
     }
     return false;
 }
 
-void ServerNetworking::SendMessage(const Message& message,
+bool ServerNetworking::SendMessage(const Message& message,
                                    PlayerConnectionPtr player_connection)
 {
-    player_connection->SendMessage(message);
+    return player_connection->SendMessage(message);
 }
 
-void ServerNetworking::SendMessage(const Message& message) {
+bool ServerNetworking::SendMessage(const Message& message) {
     if (message.ReceivingPlayer() == Networking::INVALID_PLAYER_ID) {
         // if recipient is INVALID_PLAYER_ID send message to all players
         for (ServerNetworking::const_established_iterator player_it = established_begin();
             player_it != established_end(); ++player_it)
         {
-            (*player_it)->SendMessage(message);
+            return (*player_it)->SendMessage(message);
         }
     } else {
         // send message to single player
         established_iterator it = GetPlayer(message.ReceivingPlayer());
         if (it == established_end()) {
             ErrorLogger() << "ServerNetworking::SendMessage couldn't find player with id " << message.ReceivingPlayer() << " to disconnect.  aborting";
-            return;
+            return false;
         }
         PlayerConnectionPtr player = *it;
         if (player->PlayerID() != message.ReceivingPlayer()) {
             ErrorLogger() << "ServerNetworking::SendMessage got PlayerConnectionPtr with inconsistent player id (" << message.ReceivingPlayer() << ") to what was requrested (" << message.ReceivingPlayer() << ")";
-            return;
+            return false;
         }
-        player->SendMessage(message);
+        return player->SendMessage(message);
     }
+    return false;
 }
 
 void ServerNetworking::Disconnect(int id) {
@@ -482,7 +533,8 @@ void ServerNetworking::SetHostPlayerID(int host_player_id)
 { m_host_player_id = host_player_id; }
 
 void ServerNetworking::Init() {
-    tcp::endpoint endpoint(tcp::v4(), Networking::MessagePort());
+    // use a dual stack (ipv6 + ipv4) socket
+    tcp::endpoint endpoint(tcp::v6(), Networking::MessagePort());
 
     if (GetOptionsDB().Get<bool>("singleplayer")) {
         // when hosting a single player game only accept connections from
@@ -496,6 +548,9 @@ void ServerNetworking::Init() {
     m_player_connection_acceptor.open(endpoint.protocol());
     m_player_connection_acceptor.set_option(
         boost::asio::socket_base::reuse_address(true));
+    if (endpoint.protocol() == boost::asio::ip::tcp::v6())
+        m_player_connection_acceptor.set_option(
+            boost::asio::ip::v6_only(false));  // may be true by default on some systems
     m_player_connection_acceptor.set_option(
         boost::asio::socket_base::linger(true, SOCKET_LINGER_TIME));
     m_player_connection_acceptor.bind(endpoint);
