@@ -14,13 +14,16 @@
 
 #include "MultiplayerCommon.h"
 #include "Export.h"
+#include "Serialize.h"
 #include "Directories.h"
 
 /** Contains preview information about a savegame.
   * Stored the beginning of a savefile for quick access. */
 struct FO_COMMON_API SaveGamePreviewData {
     SaveGamePreviewData();      /// Initialize with unknown markers.
+
     bool Valid() const;         /// Checks that this is a valid preview
+    void SetBinary(bool bin = true);         /// Sets the description string appropriate for a binary or XML save file header
 
     static const short  PREVIEW_PRESENT_MARKER = 0xDA;  /// A marker for the presence of the header
     short               magic_number;                   /// This should always contain PREVIEW_PRESENT_MARKER
@@ -42,6 +45,11 @@ struct FO_COMMON_API SaveGamePreviewData {
 
 BOOST_CLASS_VERSION(SaveGamePreviewData, 2);
 
+extern template FO_COMMON_API void SaveGamePreviewData::serialize<freeorion_bin_oarchive>(freeorion_bin_oarchive&, unsigned int);
+extern template FO_COMMON_API void SaveGamePreviewData::serialize<freeorion_bin_iarchive>(freeorion_bin_iarchive&, unsigned int);
+extern template FO_COMMON_API void SaveGamePreviewData::serialize<freeorion_xml_oarchive>(freeorion_xml_oarchive&, unsigned int);
+extern template FO_COMMON_API void SaveGamePreviewData::serialize<freeorion_xml_iarchive>(freeorion_xml_iarchive&, unsigned int);
+
 /** Stores all aggregated information about a save file */
 struct FO_COMMON_API FullPreview {
     std::string         filename;
@@ -65,6 +73,7 @@ private:
 };
 
 /// Get the value of column name in this preview
+/// @param full FullPreview to match for column @p name
 /// \param name The name of the column
 /// \param thin If true, tries to make the value less wide
 FO_COMMON_API std::string ColumnInPreview(const FullPreview& full, const std::string& name, bool thin = true);
